Documentation
¶
Overview ¶
Package xoofff implements Xoofff deck function according to section 3 in https://eprint.iacr.org/2018/767.pdf which primairly uses the Farfalle construction in https://eprint.iacr.org/2016/1188.pdf.
Index ¶
Constants ¶
const ( // The blocksize of Xoofff in bytes. BlockSize = 48 // KeySize is the maximal size of the key used by Xoofff, in bytes. KeySize = 48 )
Variables ¶
var ErrXoofffKeyLen = errors.New("xoofff: bad key length")
Functions ¶
This section is empty.
Types ¶
type Farfalle ¶
type Farfalle interface {
// Write absorbs more data into the Farfalle's state. It panics if called
// after Read.
io.Writer
// Read squeezes more data from the deck function.
io.Reader
// Reset resets the Farfalle to its initial state.
Reset()
// BlockSize returns the Farfalle's underlying block size.
// The Write method must be able to accept any amount
// of data, but it may operate more efficiently if all writes
// are a multiple of the block size.
BlockSize() int
}
Click to show internal directories.
Click to hide internal directories.